@@ -4,7 +4,7 @@
 #include <skalibs/iopause.h>
 #include <s6/ftrigr.h>
 
-int ftrigr_wait_and (ftrigr_t *a, uint16_t const *idlist, unsigned int n, tain_t const *deadline, tain_t *stamp)
+int ftrigr_wait_and (ftrigr_t *a, uint16_t const *idlist, unsigned int n, tain const *deadline, tain *stamp)
 {
   iopause_fd x = { -1, IOPAUSE_READ, 0 } ;
   x.fd = ftrigr_fd(a) ;
