@@ -7,7 +7,9 @@
 #include <skalibs/bitarray.h>
 #include <skalibs/tai.h>
 #include <skalibs/strerr.h>
-#include <skalibs/djbunix.h>
+#include <skalibs/cspawn.h>
+#include <skalibs/selfpipe.h>
+#include <skalibs/exec.h>
 
 #include <s6/compat.h>
 #include "s6-svlisten.h"
@@ -18,7 +20,6 @@
 int main (int argc, char const **argv, char const *const *envp)
 {
   tain deadline, tto ;
-  int spfd ;
   int argc1 ;
   int or = 0 ;
   int wantup = 1, wantready = 0 ;
@@ -49,8 +50,9 @@ int main (int argc, char const **argv, char const *const *envp)
   }
   if (argc < 3) dieusage() ;
   argc1 = s6_el_semicolon(argv) ;
-  if (!argc1 || argc == argc1 + 1) dieusage() ;
+  if (argc == argc1 + 1) dieusage() ;
   if (argc1 >= argc) strerr_dief1x(100, "unterminated servicedir block") ;
+  if (!argc1) xexec(argv + argc1 + 1) ;
   if (wantup == 2 && or)
   {
     or = 0 ;
@@ -59,7 +61,7 @@ int main (int argc, char const **argv, char const *const *envp)
 
   tain_now_set_stopwatch_g() ;
   tain_add_g(&deadline, &tto) ;
-  spfd = s6_svlisten_selfpipe_init() ;
+  s6_svlisten_selfpipe_init() ;
 
   {
     s6_svlisten_t foo = S6_SVLISTEN_ZERO ;
@@ -69,15 +71,15 @@ int main (int argc, char const **argv, char const *const *envp)
     unsigned char upstate[bitarray_div8(argc1)] ;
     unsigned char readystate[bitarray_div8(argc1)] ;
     s6_svlisten_init(argc1, argv, &foo, ids, upstate, readystate, &deadline) ;
-    pid = child_spawn0(argv[argc1 + 1], argv + argc1 + 1, envp) ;
+    pid = cspawn(argv[argc1 + 1], argv + argc1 + 1, envp, CSPAWN_FLAGS_SELFPIPE_FINISH, 0, 0) ;
     if (!pid) strerr_diefu2sys(111, "spawn ", argv[argc1 + 1]) ;
     if (wantup == 2)
     {
       wantup = 1 ;
-      e = s6_svlisten_loop(&foo, 0, 1, or, &deadline, spfd, &s6_svlisten_signal_handler) ;
+      e = s6_svlisten_loop(&foo, 0, 1, or, &deadline, selfpipe_fd(), &s6_svlisten_signal_handler) ;
       if (e) strerr_dief1x(e, "some services reported permanent failure or their supervisor died") ;
     }
-    e = s6_svlisten_loop(&foo, wantup, wantready, or, &deadline, spfd, &s6_svlisten_signal_handler) ;
+    e = s6_svlisten_loop(&foo, wantup, wantready, or, &deadline, selfpipe_fd(), &s6_svlisten_signal_handler) ;
     if (e) strerr_dief1x(e, "some services reported permanent failure or their supervisor died") ;
   }
   return 0 ;
