@@ -45,7 +45,7 @@ int main (int argc, char const *const *argv)
     argc -= l.ind ; argv += l.ind ;
     if (t) tain_from_millisecs(&deadline, t) ; else deadline = tain_infinite_relative ;
   }
-  if (!argc) dieusage() ;
+  if (!argc) return 0 ;
   tain_now_set_stopwatch_g() ;
   tain_add_g(&deadline, &deadline) ;
 
